==> huaweicloudsdkrocketmq-3.1.52-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/send_dlq_message_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SendDlqMessageResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resend_results': 'list[DeadletterResendRespResendResults]'
    }

    attribute_map = {
        'resend_results': 'resend_results'
    }

    def __init__(self, resend_results=None):
        """SendDlqMessageResponse

        The model defined in huaweicloud sdk

        :param resend_results: 重发死信消息结果。
        :type resend_results: list[:class:`huaweicloudsdkrocketmq.v2.DeadletterResendRespResendResults`]
        """
        
        super(SendDlqMessageResponse, self).__init__()

        self._resend_results = None
        self.discriminator = None

        if resend_results is not None:
            self.resend_results = resend_results

    @property
    def resend_results(self):
        """Gets the resend_results of this SendDlqMessageResponse.

        重发死信消息结果。

        :return: The resend_results of this SendDlqMessageResponse.
        :rtype: list[:class:`huaweicloudsdkrocketmq.v2.DeadletterResendRespResendResults`]
        """
        return self._resend_results

    @resend_results.setter
    def resend_results(self, resend_results):
        """Sets the resend_results of this SendDlqMessageResponse.

        重发死信消息结果。

        :param resend_results: The resend_results of this SendDlqMessageResponse.
        :type resend_results: list[:class:`huaweicloudsdkrocketmq.v2.DeadletterResendRespResendResults`]
        """
        self._resend_results = resend_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendDlqMessageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrocketmq-3.1.155-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/send_dlq_message_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SendDlqMessageResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resend_results': 'list[DeadletterResendRespResendResults]'
    }

    attribute_map = {
        'resend_results': 'resend_results'
    }

    def __init__(self, resend_results=None):
        r"""SendDlqMessageResponse

        The model defined in huaweicloud sdk

        :param resend_results: 重发死信消息结果。
        :type resend_results: list[:class:`huaweicloudsdkrocketmq.v2.DeadletterResendRespResendResults`]
        """
        
        super(SendDlqMessageResponse, self).__init__()

        self._resend_results = None
        self.discriminator = None

        if resend_results is not None:
            self.resend_results = resend_results

    @property
    def resend_results(self):
        r"""Gets the resend_results of this SendDlqMessageResponse.

        重发死信消息结果。

        :return: The resend_results of this SendDlqMessageResponse.
        :rtype: list[:class:`huaweicloudsdkrocketmq.v2.DeadletterResendRespResendResults`]
        """
        return self._resend_results

    @resend_results.setter
    def resend_results(self, resend_results):
        r"""Sets the resend_results of this SendDlqMessageResponse.

        重发死信消息结果。

        :param resend_results: The resend_results of this SendDlqMessageResponse.
        :type resend_results: list[:class:`huaweicloudsdkrocketmq.v2.DeadletterResendRespResendResults`]
        """
        self._resend_results = resend_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendDlqMessageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
